# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/datapipeline/v1/datapipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/datapipeline/v1/datapipeline.proto',
  package='github.com.metaprov.modelaapi.services.datapipeline.v1',
  syntax='proto3',
  serialized_options=b'Z6github.com/metaprov/modelaapi/services/datapipeline/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nIgithub.com/metaprov/modelaapi/services/datapipeline/v1/datapipeline.proto\x12\x36github.com.metaprov.modelaapi.services.datapipeline.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xf1\x01\n\x18ListDataPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12l\n\x06labels\x18\x02 \x03(\x0b\x32\\.github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x19ListDataPipelinesResponse\x12U\n\x05items\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineList\"m\n\x19\x43reateDataPipelineRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x1c\n\x1a\x43reateDataPipelineResponse\"m\n\x19UpdateDataPipelineRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x1c\n\x1aUpdateDataPipelineResponse\"9\n\x16GetDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x17GetDataPipelineResponse\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"9\n\x16RunDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"}\n\x17RunDataPipelineResponse\x12T\n\x08pipeline\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"<\n\x19\x44\x65leteDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19PauseDataPipelineResponse\";\n\x18PauseDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1aResumeDataPipelineResponse\"<\n\x19ResumeDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1a\x44\x65leteDataPipelineResponse2\xe9\x0e\n\x13\x44\x61taPipelineService\x12\xd3\x01\n\x11ListDataPipelines\x12P.github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest\x1aQ.github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/datapipelines\x12\xd9\x01\n\x12\x43reateDataPipeline\x12Q.github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineRequest\x1aR.github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/datapipelines:\x01*\x12\xe0\x01\n\x0fGetDataPipeline\x12N.github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineRequest\x1aO.github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/datapipelines/{namespace}/{name}\x12\x98\x02\n\x12UpdateDataPipeline\x12Q.github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineRequest\x1aR.github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineResponse\"[\x82\xd3\xe4\x93\x02U\x1aP/v1/datapipelines/{datapipeline.metadata.namespace}/{datapipeline.metadata.name}:\x01*\x12\xed\x01\n\x12\x44\x65leteDataPipeline\x12Q.github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineRequest\x1aR.github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineResponse\"0\x82\xd3\xe4\x93\x02**(/api/v1/datapipelines/{namespace}/{name}\x12\xe0\x01\n\x11PauseDataPipeline\x12P.github.com.metaprov.modelaapi.services.datapipeline.v1.PauseDataPipelineRequest\x1aQ.github.com.metaprov.modelaapi.services.datapipeline.v1.PauseDataPipelineResponse\"&\x82\xd3\xe4\x93\x02 \"\x1e/v1/datapipelines/{name}:pause\x12\xe3\x01\n\x12ResumeDataPipeline\x12Q.github.com.metaprov.modelaapi.services.datapipeline.v1.ResumeDataPipelineRequest\x1aR.github.com.metaprov.modelaapi.services.datapipeline.v1.ResumeDataPipelineResponse\"&\x82\xd3\xe4\x93\x02 \"\x1e/v1/datapipelines/{name}:pause\x12\xe8\x01\n\x0fRunDataPipeline\x12N.github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineRequest\x1aO.github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineResponse\"4\x82\xd3\xe4\x93\x02.\",/api/v1/datapipelines/{namespace}/{name}:runB8Z6github.com/metaprov/modelaapi/services/datapipeline/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTDATAPIPELINESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=475,
)

_LISTDATAPIPELINESREQUEST = _descriptor.Descriptor(
  name='ListDataPipelinesRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDATAPIPELINESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=475,
)


_LISTDATAPIPELINESRESPONSE = _descriptor.Descriptor(
  name='ListDataPipelinesResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=591,
)


_CREATEDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='CreateDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=702,
)


_CREATEDATAPIPELINERESPONSE = _descriptor.Descriptor(
  name='CreateDataPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=732,
)


_UPDATEDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='UpdateDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=734,
  serialized_end=843,
)


_UPDATEDATAPIPELINERESPONSE = _descriptor.Descriptor(
  name='UpdateDataPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=873,
)


_GETDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='GetDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=932,
)


_GETDATAPIPELINERESPONSE = _descriptor.Descriptor(
  name='GetDataPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=1055,
)


_RUNDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='RunDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1057,
  serialized_end=1114,
)


_RUNDATAPIPELINERESPONSE = _descriptor.Descriptor(
  name='RunDataPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineResponse.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1116,
  serialized_end=1241,
)


_DELETEDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='DeleteDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1243,
  serialized_end=1303,
)


_PAUSEDATAPIPELINERESPONSE = _descriptor.Descriptor(
  name='PauseDataPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.PauseDataPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1305,
  serialized_end=1332,
)


_PAUSEDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='PauseDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.PauseDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.PauseDataPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.PauseDataPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1334,
  serialized_end=1393,
)


_RESUMEDATAPIPELINERESPONSE = _descriptor.Descriptor(
  name='ResumeDataPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ResumeDataPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1395,
  serialized_end=1423,
)


_RESUMEDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='ResumeDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ResumeDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ResumeDataPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.ResumeDataPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1425,
  serialized_end=1485,
)


_DELETEDATAPIPELINERESPONSE = _descriptor.Descriptor(
  name='DeleteDataPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1487,
  serialized_end=1515,
)

_LISTDATAPIPELINESREQUEST_LABELSENTRY.containing_type = _LISTDATAPIPELINESREQUEST
_LISTDATAPIPELINESREQUEST.fields_by_name['labels'].message_type = _LISTDATAPIPELINESREQUEST_LABELSENTRY
_LISTDATAPIPELINESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINELIST
_CREATEDATAPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE
_UPDATEDATAPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE
_GETDATAPIPELINERESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE
_RUNDATAPIPELINERESPONSE.fields_by_name['pipeline'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE
DESCRIPTOR.message_types_by_name['ListDataPipelinesRequest'] = _LISTDATAPIPELINESREQUEST
DESCRIPTOR.message_types_by_name['ListDataPipelinesResponse'] = _LISTDATAPIPELINESRESPONSE
DESCRIPTOR.message_types_by_name['CreateDataPipelineRequest'] = _CREATEDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['CreateDataPipelineResponse'] = _CREATEDATAPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['UpdateDataPipelineRequest'] = _UPDATEDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataPipelineResponse'] = _UPDATEDATAPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['GetDataPipelineRequest'] = _GETDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['GetDataPipelineResponse'] = _GETDATAPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['RunDataPipelineRequest'] = _RUNDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['RunDataPipelineResponse'] = _RUNDATAPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['DeleteDataPipelineRequest'] = _DELETEDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['PauseDataPipelineResponse'] = _PAUSEDATAPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['PauseDataPipelineRequest'] = _PAUSEDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ResumeDataPipelineResponse'] = _RESUMEDATAPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['ResumeDataPipelineRequest'] = _RESUMEDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataPipelineResponse'] = _DELETEDATAPIPELINERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListDataPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelinesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAPIPELINESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesRequest)
  })
_sym_db.RegisterMessage(ListDataPipelinesRequest)
_sym_db.RegisterMessage(ListDataPipelinesRequest.LabelsEntry)

ListDataPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.ListDataPipelinesResponse)
  })
_sym_db.RegisterMessage(ListDataPipelinesResponse)

CreateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRequest)

CreateDataPipelineResponse = _reflection.GeneratedProtocolMessageType('CreateDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.CreateDataPipelineResponse)
  })
_sym_db.RegisterMessage(CreateDataPipelineResponse)

UpdateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRequest)

UpdateDataPipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.UpdateDataPipelineResponse)
  })
_sym_db.RegisterMessage(UpdateDataPipelineResponse)

GetDataPipelineRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRequest)

GetDataPipelineResponse = _reflection.GeneratedProtocolMessageType('GetDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.GetDataPipelineResponse)
  })
_sym_db.RegisterMessage(GetDataPipelineResponse)

RunDataPipelineRequest = _reflection.GeneratedProtocolMessageType('RunDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineRequest)
  })
_sym_db.RegisterMessage(RunDataPipelineRequest)

RunDataPipelineResponse = _reflection.GeneratedProtocolMessageType('RunDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.RunDataPipelineResponse)
  })
_sym_db.RegisterMessage(RunDataPipelineResponse)

DeleteDataPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRequest)

PauseDataPipelineResponse = _reflection.GeneratedProtocolMessageType('PauseDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.PauseDataPipelineResponse)
  })
_sym_db.RegisterMessage(PauseDataPipelineResponse)

PauseDataPipelineRequest = _reflection.GeneratedProtocolMessageType('PauseDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.PauseDataPipelineRequest)
  })
_sym_db.RegisterMessage(PauseDataPipelineRequest)

ResumeDataPipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.ResumeDataPipelineResponse)
  })
_sym_db.RegisterMessage(ResumeDataPipelineResponse)

ResumeDataPipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.ResumeDataPipelineRequest)
  })
_sym_db.RegisterMessage(ResumeDataPipelineRequest)

DeleteDataPipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipeline.v1.datapipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipeline.v1.DeleteDataPipelineResponse)
  })
_sym_db.RegisterMessage(DeleteDataPipelineResponse)


DESCRIPTOR._options = None
_LISTDATAPIPELINESREQUEST_LABELSENTRY._options = None

_DATAPIPELINESERVICE = _descriptor.ServiceDescriptor(
  name='DataPipelineService',
  full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1518,
  serialized_end=3415,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDataPipelines',
    full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService.ListDataPipelines',
    index=0,
    containing_service=None,
    input_type=_LISTDATAPIPELINESREQUEST,
    output_type=_LISTDATAPIPELINESRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/v1/datapipelines',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService.CreateDataPipeline',
    index=1,
    containing_service=None,
    input_type=_CREATEDATAPIPELINEREQUEST,
    output_type=_CREATEDATAPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002\026\"\021/v1/datapipelines:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService.GetDataPipeline',
    index=2,
    containing_service=None,
    input_type=_GETDATAPIPELINEREQUEST,
    output_type=_GETDATAPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/v1/datapipelines/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService.UpdateDataPipeline',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATAPIPELINEREQUEST,
    output_type=_UPDATEDATAPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002U\032P/v1/datapipelines/{datapipeline.metadata.namespace}/{datapipeline.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService.DeleteDataPipeline',
    index=4,
    containing_service=None,
    input_type=_DELETEDATAPIPELINEREQUEST,
    output_type=_DELETEDATAPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002**(/api/v1/datapipelines/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService.PauseDataPipeline',
    index=5,
    containing_service=None,
    input_type=_PAUSEDATAPIPELINEREQUEST,
    output_type=_PAUSEDATAPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\036/v1/datapipelines/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService.ResumeDataPipeline',
    index=6,
    containing_service=None,
    input_type=_RESUMEDATAPIPELINEREQUEST,
    output_type=_RESUMEDATAPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\036/v1/datapipelines/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.datapipeline.v1.DataPipelineService.RunDataPipeline',
    index=7,
    containing_service=None,
    input_type=_RUNDATAPIPELINEREQUEST,
    output_type=_RUNDATAPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002.\",/api/v1/datapipelines/{namespace}/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPIPELINESERVICE)

DESCRIPTOR.services_by_name['DataPipelineService'] = _DATAPIPELINESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/lab/v1/lab.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/lab/v1/lab.proto',
  package='github.com.metaprov.modelaapi.services.lab.v1',
  syntax='proto3',
  serialized_options=b'Z-github.com/metaprov/modelaapi/services/lab/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7github.com/metaprov/modelaapi/services/lab/v1/lab.proto\x12-github.com.metaprov.modelaapi.services.lab.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xaf\x01\n\x0fListLabsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12Z\n\x06labels\x18\x03 \x03(\x0b\x32J.github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x10ListLabsResponse\x12M\n\x05items\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.LabList\"\r\n\x0bLabResponse\"\\\n\x10\x43reateLabRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x13\n\x11\x43reateLabResponse\"\\\n\x10UpdateLabRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x13\n\x11UpdateLabResponse\"0\n\rGetLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"h\n\x0eGetLabResponse\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17GetLabNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x18GetLabNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"3\n\x10\x44\x65leteLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteLabResponse2\xdf\x06\n\nLabService\x12\xa1\x01\n\x08ListLabs\x12>.github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest\x1a?.github.com.metaprov.modelaapi.services.lab.v1.ListLabsResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/api/v1/labs\x12\xa3\x01\n\tCreateLab\x12?.github.com.metaprov.modelaapi.services.lab.v1.CreateLabRequest\x1a@.github.com.metaprov.modelaapi.services.lab.v1.CreateLabResponse\"\x13\x82\xd3\xe4\x93\x02\r\"\x08/v1/labs:\x01*\x12\xaf\x01\n\x06GetLab\x12<.github.com.metaprov.modelaapi.services.lab.v1.GetLabRequest\x1a=.github.com.metaprov.modelaapi.services.lab.v1.GetLabResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/labs/{lab.metadata.name}\x12\xaa\x01\n\tUpdateLab\x12?.github.com.metaprov.modelaapi.services.lab.v1.UpdateLabRequest\x1a@.github.com.metaprov.modelaapi.services.lab.v1.UpdateLabResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x1a\x0f/v1/labs/{name}:\x01*\x12\xa7\x01\n\tDeleteLab\x12?.github.com.metaprov.modelaapi.services.lab.v1.DeleteLabRequest\x1a@.github.com.metaprov.modelaapi.services.lab.v1.DeleteLabResponse\"\x17\x82\xd3\xe4\x93\x02\x11*\x0f/v1/labs/{name}B/Z-github.com/metaprov/modelaapi/services/lab/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTLABSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=446,
)

_LISTLABSREQUEST = _descriptor.Descriptor(
  name='ListLabsRequest',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTLABSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=446,
)


_LISTLABSRESPONSE = _descriptor.Descriptor(
  name='ListLabsResponse',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.ListLabsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.lab.v1.ListLabsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=545,
)


_LABRESPONSE = _descriptor.Descriptor(
  name='LabResponse',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.LabResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=560,
)


_CREATELABREQUEST = _descriptor.Descriptor(
  name='CreateLabRequest',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.CreateLabRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.lab.v1.CreateLabRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=654,
)


_CREATELABRESPONSE = _descriptor.Descriptor(
  name='CreateLabResponse',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.CreateLabResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=656,
  serialized_end=675,
)


_UPDATELABREQUEST = _descriptor.Descriptor(
  name='UpdateLabRequest',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.UpdateLabRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.lab.v1.UpdateLabRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=769,
)


_UPDATELABRESPONSE = _descriptor.Descriptor(
  name='UpdateLabResponse',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.UpdateLabResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=790,
)


_GETLABREQUEST = _descriptor.Descriptor(
  name='GetLabRequest',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=792,
  serialized_end=840,
)


_GETLABRESPONSE = _descriptor.Descriptor(
  name='GetLabResponse',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=842,
  serialized_end=946,
)


_GETLABNAMESPACESREQUEST = _descriptor.Descriptor(
  name='GetLabNamespacesRequest',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1006,
)


_GETLABNAMESPACESRESPONSE = _descriptor.Descriptor(
  name='GetLabNamespacesResponse',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesResponse.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1119,
)


_DELETELABREQUEST = _descriptor.Descriptor(
  name='DeleteLabRequest',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.DeleteLabRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.lab.v1.DeleteLabRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.lab.v1.DeleteLabRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1121,
  serialized_end=1172,
)


_DELETELABRESPONSE = _descriptor.Descriptor(
  name='DeleteLabResponse',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.DeleteLabResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1193,
)

_LISTLABSREQUEST_LABELSENTRY.containing_type = _LISTLABSREQUEST
_LISTLABSREQUEST.fields_by_name['labels'].message_type = _LISTLABSREQUEST_LABELSENTRY
_LISTLABSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LABLIST
_CREATELABREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LAB
_UPDATELABREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LAB
_GETLABRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LAB
_GETLABNAMESPACESRESPONSE.fields_by_name['namespaces'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._NAMESPACEINFO
DESCRIPTOR.message_types_by_name['ListLabsRequest'] = _LISTLABSREQUEST
DESCRIPTOR.message_types_by_name['ListLabsResponse'] = _LISTLABSRESPONSE
DESCRIPTOR.message_types_by_name['LabResponse'] = _LABRESPONSE
DESCRIPTOR.message_types_by_name['CreateLabRequest'] = _CREATELABREQUEST
DESCRIPTOR.message_types_by_name['CreateLabResponse'] = _CREATELABRESPONSE
DESCRIPTOR.message_types_by_name['UpdateLabRequest'] = _UPDATELABREQUEST
DESCRIPTOR.message_types_by_name['UpdateLabResponse'] = _UPDATELABRESPONSE
DESCRIPTOR.message_types_by_name['GetLabRequest'] = _GETLABREQUEST
DESCRIPTOR.message_types_by_name['GetLabResponse'] = _GETLABRESPONSE
DESCRIPTOR.message_types_by_name['GetLabNamespacesRequest'] = _GETLABNAMESPACESREQUEST
DESCRIPTOR.message_types_by_name['GetLabNamespacesResponse'] = _GETLABNAMESPACESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteLabRequest'] = _DELETELABREQUEST
DESCRIPTOR.message_types_by_name['DeleteLabResponse'] = _DELETELABRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListLabsRequest = _reflection.GeneratedProtocolMessageType('ListLabsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLABSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLABSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest)
  })
_sym_db.RegisterMessage(ListLabsRequest)
_sym_db.RegisterMessage(ListLabsRequest.LabelsEntry)

ListLabsResponse = _reflection.GeneratedProtocolMessageType('ListLabsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.ListLabsResponse)
  })
_sym_db.RegisterMessage(ListLabsResponse)

LabResponse = _reflection.GeneratedProtocolMessageType('LabResponse', (_message.Message,), {
  'DESCRIPTOR' : _LABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.LabResponse)
  })
_sym_db.RegisterMessage(LabResponse)

CreateLabRequest = _reflection.GeneratedProtocolMessageType('CreateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.CreateLabRequest)
  })
_sym_db.RegisterMessage(CreateLabRequest)

CreateLabResponse = _reflection.GeneratedProtocolMessageType('CreateLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.CreateLabResponse)
  })
_sym_db.RegisterMessage(CreateLabResponse)

UpdateLabRequest = _reflection.GeneratedProtocolMessageType('UpdateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.UpdateLabRequest)
  })
_sym_db.RegisterMessage(UpdateLabRequest)

UpdateLabResponse = _reflection.GeneratedProtocolMessageType('UpdateLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.UpdateLabResponse)
  })
_sym_db.RegisterMessage(UpdateLabResponse)

GetLabRequest = _reflection.GeneratedProtocolMessageType('GetLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabRequest)
  })
_sym_db.RegisterMessage(GetLabRequest)

GetLabResponse = _reflection.GeneratedProtocolMessageType('GetLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabResponse)
  })
_sym_db.RegisterMessage(GetLabResponse)

GetLabNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetLabNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesRequest)
  })
_sym_db.RegisterMessage(GetLabNamespacesRequest)

GetLabNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetLabNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesResponse)
  })
_sym_db.RegisterMessage(GetLabNamespacesResponse)

DeleteLabRequest = _reflection.GeneratedProtocolMessageType('DeleteLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.DeleteLabRequest)
  })
_sym_db.RegisterMessage(DeleteLabRequest)

DeleteLabResponse = _reflection.GeneratedProtocolMessageType('DeleteLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.DeleteLabResponse)
  })
_sym_db.RegisterMessage(DeleteLabResponse)


DESCRIPTOR._options = None
_LISTLABSREQUEST_LABELSENTRY._options = None

_LABSERVICE = _descriptor.ServiceDescriptor(
  name='LabService',
  full_name='github.com.metaprov.modelaapi.services.lab.v1.LabService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1196,
  serialized_end=2059,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListLabs',
    full_name='github.com.metaprov.modelaapi.services.lab.v1.LabService.ListLabs',
    index=0,
    containing_service=None,
    input_type=_LISTLABSREQUEST,
    output_type=_LISTLABSRESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/api/v1/labs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLab',
    full_name='github.com.metaprov.modelaapi.services.lab.v1.LabService.CreateLab',
    index=1,
    containing_service=None,
    input_type=_CREATELABREQUEST,
    output_type=_CREATELABRESPONSE,
    serialized_options=b'\202\323\344\223\002\r\"\010/v1/labs:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLab',
    full_name='github.com.metaprov.modelaapi.services.lab.v1.LabService.GetLab',
    index=2,
    containing_service=None,
    input_type=_GETLABREQUEST,
    output_type=_GETLABRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /api/v1/labs/{lab.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLab',
    full_name='github.com.metaprov.modelaapi.services.lab.v1.LabService.UpdateLab',
    index=3,
    containing_service=None,
    input_type=_UPDATELABREQUEST,
    output_type=_UPDATELABRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\032\017/v1/labs/{name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLab',
    full_name='github.com.metaprov.modelaapi.services.lab.v1.LabService.DeleteLab',
    index=4,
    containing_service=None,
    input_type=_DELETELABREQUEST,
    output_type=_DELETELABRESPONSE,
    serialized_options=b'\202\323\344\223\002\021*\017/v1/labs/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LABSERVICE)

DESCRIPTOR.services_by_name['LabService'] = _LABSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/feature/v1/feature.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/feature/v1/feature.proto',
  package='github.com.metaprov.modelaapi.services.feature.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/feature/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/feature/v1/feature.proto\x12\x31github.com.metaprov.modelaapi.services.feature.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xbb\x01\n\x13ListFeaturesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x14ListFeaturesResponse\x12P\n\x05items\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureList\"c\n\x14\x43reateFeatureRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x17\n\x15\x43reateFeatureResponse\"c\n\x14UpdateFeatureRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x17\n\x15UpdateFeatureResponse\"4\n\x11GetFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x12GetFeatureResponse\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteFeatureResponse2\xbc\x07\n\x0e\x46\x65\x61tureService\x12\xb5\x01\n\x0cListFeatures\x12\x46.github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest\x1aG.github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/features\x12\xbb\x01\n\rCreateFeature\x12G.github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureRequest\x1aH.github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/features:\x01*\x12\xb6\x01\n\nGetFeature\x12\x44.github.com.metaprov.modelaapi.services.feature.v1.GetFeatureRequest\x1a\x45.github.com.metaprov.modelaapi.services.feature.v1.GetFeatureResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/features/{name}\x12\xd3\x01\n\rUpdateFeature\x12G.github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureRequest\x1aH.github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureResponse\"/\x82\xd3\xe4\x93\x02)\x1a$/v1/features/{feature.metadata.name}:\x01*\x12\xa4\x01\n\rDeleteFeature\x12G.github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureRequest\x1aH.github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureResponse\"\x00\x42\x33Z1github.com/metaprov/modelaapi/services/feature/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTFEATURESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=406,
)

_LISTFEATURESREQUEST = _descriptor.Descriptor(
  name='ListFeaturesRequest',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTFEATURESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=406,
)


_LISTFEATURESRESPONSE = _descriptor.Descriptor(
  name='ListFeaturesResponse',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=408,
  serialized_end=512,
)


_CREATEFEATUREREQUEST = _descriptor.Descriptor(
  name='CreateFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=613,
)


_CREATEFEATURERESPONSE = _descriptor.Descriptor(
  name='CreateFeatureResponse',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=638,
)


_UPDATEFEATUREREQUEST = _descriptor.Descriptor(
  name='UpdateFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=739,
)


_UPDATEFEATURERESPONSE = _descriptor.Descriptor(
  name='UpdateFeatureResponse',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=764,
)


_GETFEATUREREQUEST = _descriptor.Descriptor(
  name='GetFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.GetFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.feature.v1.GetFeatureRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.feature.v1.GetFeatureRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=818,
)


_GETFEATURERESPONSE = _descriptor.Descriptor(
  name='GetFeatureResponse',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.GetFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.feature.v1.GetFeatureResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.feature.v1.GetFeatureResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=820,
  serialized_end=931,
)


_DELETEFEATUREREQUEST = _descriptor.Descriptor(
  name='DeleteFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=933,
  serialized_end=988,
)


_DELETEFEATURERESPONSE = _descriptor.Descriptor(
  name='DeleteFeatureResponse',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1013,
)

_LISTFEATURESREQUEST_LABELSENTRY.containing_type = _LISTFEATURESREQUEST
_LISTFEATURESREQUEST.fields_by_name['labels'].message_type = _LISTFEATURESREQUEST_LABELSENTRY
_LISTFEATURESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURELIST
_CREATEFEATUREREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE
_UPDATEFEATUREREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE
_GETFEATURERESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE
DESCRIPTOR.message_types_by_name['ListFeaturesRequest'] = _LISTFEATURESREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturesResponse'] = _LISTFEATURESRESPONSE
DESCRIPTOR.message_types_by_name['CreateFeatureRequest'] = _CREATEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['CreateFeatureResponse'] = _CREATEFEATURERESPONSE
DESCRIPTOR.message_types_by_name['UpdateFeatureRequest'] = _UPDATEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeatureResponse'] = _UPDATEFEATURERESPONSE
DESCRIPTOR.message_types_by_name['GetFeatureRequest'] = _GETFEATUREREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureResponse'] = _GETFEATURERESPONSE
DESCRIPTOR.message_types_by_name['DeleteFeatureRequest'] = _DELETEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeatureResponse'] = _DELETEFEATURERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListFeaturesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATURESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATURESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest)
  })
_sym_db.RegisterMessage(ListFeaturesRequest)
_sym_db.RegisterMessage(ListFeaturesRequest.LabelsEntry)

ListFeaturesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesResponse)
  })
_sym_db.RegisterMessage(ListFeaturesResponse)

CreateFeatureRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureRequest)
  })
_sym_db.RegisterMessage(CreateFeatureRequest)

CreateFeatureResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureResponse)
  })
_sym_db.RegisterMessage(CreateFeatureResponse)

UpdateFeatureRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureRequest)

UpdateFeatureResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureResponse)

GetFeatureRequest = _reflection.GeneratedProtocolMessageType('GetFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.GetFeatureRequest)
  })
_sym_db.RegisterMessage(GetFeatureRequest)

GetFeatureResponse = _reflection.GeneratedProtocolMessageType('GetFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.GetFeatureResponse)
  })
_sym_db.RegisterMessage(GetFeatureResponse)

DeleteFeatureRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureRequest)

DeleteFeatureResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureResponse)


DESCRIPTOR._options = None
_LISTFEATURESREQUEST_LABELSENTRY._options = None

_FEATURESERVICE = _descriptor.ServiceDescriptor(
  name='FeatureService',
  full_name='github.com.metaprov.modelaapi.services.feature.v1.FeatureService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1016,
  serialized_end=1972,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListFeatures',
    full_name='github.com.metaprov.modelaapi.services.feature.v1.FeatureService.ListFeatures',
    index=0,
    containing_service=None,
    input_type=_LISTFEATURESREQUEST,
    output_type=_LISTFEATURESRESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/v1/features',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeature',
    full_name='github.com.metaprov.modelaapi.services.feature.v1.FeatureService.CreateFeature',
    index=1,
    containing_service=None,
    input_type=_CREATEFEATUREREQUEST,
    output_type=_CREATEFEATURERESPONSE,
    serialized_options=b'\202\323\344\223\002\021\"\014/v1/features:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeature',
    full_name='github.com.metaprov.modelaapi.services.feature.v1.FeatureService.GetFeature',
    index=2,
    containing_service=None,
    input_type=_GETFEATUREREQUEST,
    output_type=_GETFEATURERESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1/features/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeature',
    full_name='github.com.metaprov.modelaapi.services.feature.v1.FeatureService.UpdateFeature',
    index=3,
    containing_service=None,
    input_type=_UPDATEFEATUREREQUEST,
    output_type=_UPDATEFEATURERESPONSE,
    serialized_options=b'\202\323\344\223\002)\032$/v1/features/{feature.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeature',
    full_name='github.com.metaprov.modelaapi.services.feature.v1.FeatureService.DeleteFeature',
    index=4,
    containing_service=None,
    input_type=_DELETEFEATUREREQUEST,
    output_type=_DELETEFEATURERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEATURESERVICE)

DESCRIPTOR.services_by_name['FeatureService'] = _FEATURESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/runbook/v1/runbook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/runbook/v1/runbook.proto',
  package='github.com.metaprov.modelaapi.services.runbook.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/runbook/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/runbook/v1/runbook.proto\x12\x31github.com.metaprov.modelaapi.services.runbook.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\"\xbb\x01\n\x13ListRunBooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x03 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x14ListRunBooksResponse\x12P\n\x05items\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookList\"c\n\x14\x43reateRunBookRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x17\n\x15\x43reateRunBookResponse\"c\n\x14UpdateRunBookRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x17\n\x15UpdateRunBookResponse\"4\n\x11GetRunBookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x12GetRunBookResponse\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteRunBookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteRunBookResponse2\xbc\x07\n\x0eRunBookService\x12\xb5\x01\n\x0cListRunBooks\x12\x46.github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest\x1aG.github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/runbooks\x12\xbb\x01\n\rCreateRunBook\x12G.github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookRequest\x1aH.github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/runbooks:\x01*\x12\xb6\x01\n\nGetRunBook\x12\x44.github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookRequest\x1a\x45.github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/runbooks/{name}\x12\xd3\x01\n\rUpdateRunBook\x12G.github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookRequest\x1aH.github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookResponse\"/\x82\xd3\xe4\x93\x02)\x1a$/v1/runbooks/{runbook.metadata.name}:\x01*\x12\xa4\x01\n\rDeleteRunBook\x12G.github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookRequest\x1aH.github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookResponse\"\x00\x42\x33Z1github.com/metaprov/modelaapi/services/runbook/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTRUNBOOKSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=406,
)

_LISTRUNBOOKSREQUEST = _descriptor.Descriptor(
  name='ListRunBooksRequest',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTRUNBOOKSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=406,
)


_LISTRUNBOOKSRESPONSE = _descriptor.Descriptor(
  name='ListRunBooksResponse',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=408,
  serialized_end=512,
)


_CREATERUNBOOKREQUEST = _descriptor.Descriptor(
  name='CreateRunBookRequest',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=613,
)


_CREATERUNBOOKRESPONSE = _descriptor.Descriptor(
  name='CreateRunBookResponse',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=638,
)


_UPDATERUNBOOKREQUEST = _descriptor.Descriptor(
  name='UpdateRunBookRequest',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=739,
)


_UPDATERUNBOOKRESPONSE = _descriptor.Descriptor(
  name='UpdateRunBookResponse',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=764,
)


_GETRUNBOOKREQUEST = _descriptor.Descriptor(
  name='GetRunBookRequest',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=818,
)


_GETRUNBOOKRESPONSE = _descriptor.Descriptor(
  name='GetRunBookResponse',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=820,
  serialized_end=931,
)


_DELETERUNBOOKREQUEST = _descriptor.Descriptor(
  name='DeleteRunBookRequest',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=933,
  serialized_end=988,
)


_DELETERUNBOOKRESPONSE = _descriptor.Descriptor(
  name='DeleteRunBookResponse',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1013,
)

_LISTRUNBOOKSREQUEST_LABELSENTRY.containing_type = _LISTRUNBOOKSREQUEST
_LISTRUNBOOKSREQUEST.fields_by_name['labels'].message_type = _LISTRUNBOOKSREQUEST_LABELSENTRY
_LISTRUNBOOKSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOKLIST
_CREATERUNBOOKREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOK
_UPDATERUNBOOKREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOK
_GETRUNBOOKRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOK
DESCRIPTOR.message_types_by_name['ListRunBooksRequest'] = _LISTRUNBOOKSREQUEST
DESCRIPTOR.message_types_by_name['ListRunBooksResponse'] = _LISTRUNBOOKSRESPONSE
DESCRIPTOR.message_types_by_name['CreateRunBookRequest'] = _CREATERUNBOOKREQUEST
DESCRIPTOR.message_types_by_name['CreateRunBookResponse'] = _CREATERUNBOOKRESPONSE
DESCRIPTOR.message_types_by_name['UpdateRunBookRequest'] = _UPDATERUNBOOKREQUEST
DESCRIPTOR.message_types_by_name['UpdateRunBookResponse'] = _UPDATERUNBOOKRESPONSE
DESCRIPTOR.message_types_by_name['GetRunBookRequest'] = _GETRUNBOOKREQUEST
DESCRIPTOR.message_types_by_name['GetRunBookResponse'] = _GETRUNBOOKRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRunBookRequest'] = _DELETERUNBOOKREQUEST
DESCRIPTOR.message_types_by_name['DeleteRunBookResponse'] = _DELETERUNBOOKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListRunBooksRequest = _reflection.GeneratedProtocolMessageType('ListRunBooksRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTRUNBOOKSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTRUNBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest)
  })
_sym_db.RegisterMessage(ListRunBooksRequest)
_sym_db.RegisterMessage(ListRunBooksRequest.LabelsEntry)

ListRunBooksResponse = _reflection.GeneratedProtocolMessageType('ListRunBooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksResponse)
  })
_sym_db.RegisterMessage(ListRunBooksResponse)

CreateRunBookRequest = _reflection.GeneratedProtocolMessageType('CreateRunBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookRequest)
  })
_sym_db.RegisterMessage(CreateRunBookRequest)

CreateRunBookResponse = _reflection.GeneratedProtocolMessageType('CreateRunBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookResponse)
  })
_sym_db.RegisterMessage(CreateRunBookResponse)

UpdateRunBookRequest = _reflection.GeneratedProtocolMessageType('UpdateRunBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookRequest)
  })
_sym_db.RegisterMessage(UpdateRunBookRequest)

UpdateRunBookResponse = _reflection.GeneratedProtocolMessageType('UpdateRunBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookResponse)
  })
_sym_db.RegisterMessage(UpdateRunBookResponse)

GetRunBookRequest = _reflection.GeneratedProtocolMessageType('GetRunBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookRequest)
  })
_sym_db.RegisterMessage(GetRunBookRequest)

GetRunBookResponse = _reflection.GeneratedProtocolMessageType('GetRunBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookResponse)
  })
_sym_db.RegisterMessage(GetRunBookResponse)

DeleteRunBookRequest = _reflection.GeneratedProtocolMessageType('DeleteRunBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookRequest)
  })
_sym_db.RegisterMessage(DeleteRunBookRequest)

DeleteRunBookResponse = _reflection.GeneratedProtocolMessageType('DeleteRunBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookResponse)
  })
_sym_db.RegisterMessage(DeleteRunBookResponse)


DESCRIPTOR._options = None
_LISTRUNBOOKSREQUEST_LABELSENTRY._options = None

_RUNBOOKSERVICE = _descriptor.ServiceDescriptor(
  name='RunBookService',
  full_name='github.com.metaprov.modelaapi.services.runbook.v1.RunBookService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1016,
  serialized_end=1972,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListRunBooks',
    full_name='github.com.metaprov.modelaapi.services.runbook.v1.RunBookService.ListRunBooks',
    index=0,
    containing_service=None,
    input_type=_LISTRUNBOOKSREQUEST,
    output_type=_LISTRUNBOOKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/v1/runbooks',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRunBook',
    full_name='github.com.metaprov.modelaapi.services.runbook.v1.RunBookService.CreateRunBook',
    index=1,
    containing_service=None,
    input_type=_CREATERUNBOOKREQUEST,
    output_type=_CREATERUNBOOKRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\"\014/v1/runbooks:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRunBook',
    full_name='github.com.metaprov.modelaapi.services.runbook.v1.RunBookService.GetRunBook',
    index=2,
    containing_service=None,
    input_type=_GETRUNBOOKREQUEST,
    output_type=_GETRUNBOOKRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1/runbooks/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRunBook',
    full_name='github.com.metaprov.modelaapi.services.runbook.v1.RunBookService.UpdateRunBook',
    index=3,
    containing_service=None,
    input_type=_UPDATERUNBOOKREQUEST,
    output_type=_UPDATERUNBOOKRESPONSE,
    serialized_options=b'\202\323\344\223\002)\032$/v1/runbooks/{runbook.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRunBook',
    full_name='github.com.metaprov.modelaapi.services.runbook.v1.RunBookService.DeleteRunBook',
    index=4,
    containing_service=None,
    input_type=_DELETERUNBOOKREQUEST,
    output_type=_DELETERUNBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RUNBOOKSERVICE)

DESCRIPTOR.services_by_name['RunBookService'] = _RUNBOOKSERVICE

# @@protoc_insertion_point(module_scope)
